"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fixer_1 = require("../utils/fixer");
const parseExpectCall_1 = require("../utils/parseExpectCall");
exports.default = {
    create(context) {
        return {
            CallExpression(node) {
                const expectCall = (0, parseExpectCall_1.parseExpectCall)(node);
                if (expectCall?.matcherName === 'toEqual') {
                    context.report({
                        node: expectCall.matcher,
                        messageId: 'useToStrictEqual',
                        suggest: [
                            {
                                messageId: 'suggestReplaceWithStrictEqual',
                                fix: (fixer) => {
                                    return (0, fixer_1.replaceAccessorFixer)(fixer, expectCall.matcher, 'toStrictEqual');
                                },
                            },
                        ],
                    });
                }
            },
        };
    },
    meta: {
        docs: {
            category: 'Best Practices',
            description: 'Suggest using `toStrictEqual()`',
            recommended: false,
            url: 'https://github.com/playwright-community/eslint-plugin-playwright/tree/main/docs/rules/prefer-strict-equal.md',
        },
        messages: {
            useToStrictEqual: 'Use toStrictEqual() instead',
            suggestReplaceWithStrictEqual: 'Replace with `toStrictEqual()`',
        },
        fixable: 'code',
        type: 'suggestion',
        hasSuggestions: true,
        schema: [],
    },
};
